#
# Conditional build:
%bcond_without	python2	# CPython 2.x module
%bcond_with	python3	# CPython 3.x module
%bcond_without	doc	# Sphinx documentation
%bcond_without	tests	# unit tests

Summary:	Crypthography library for Python 2
Summary(pl.UTF-8):	Biblioteka Cryptography dla Pythona 2
Name:		python-cryptography
Version:	3.3.2
Release:	1
License:	Apache v2.0 or BSD
Group:		Libraries/Python
#Source0Download: https://pypi.org/simple/cryptography/
Source0:	https://files.pythonhosted.org/packages/source/c/cryptography/cryptography-%{version}.tar.gz
# Source0-md5:	e2ce2ec8a63965fad351f36ed70fde4b
#Source1Download: https://pypi.org/simple/cryptography_vectors/
Source1:	https://files.pythonhosted.org/packages/source/c/cryptography-vectors/cryptography_vectors-%{version}.tar.gz
# Source1-md5:	79785df0f2d43f05895991b7e067a2ce
Patch0:		openssl3.patch
Patch1:		openssl3-tests.patch
Patch2:		%{name}-openssl3.0.1.patch
URL:		https://cryptography.io/
BuildRequires:	openssl-devel >= 3.0.0
BuildRequires:	rpm-build >= 4.6
BuildRequires:	rpm-pythonprov >= 5.4.15-48
BuildRequires:	rpmbuild(macros) >= 1.714
%if %{with python2}
BuildRequires:	python-cffi >= 1.12
BuildRequires:	python-devel >= 1:2.7
BuildRequires:	python-enum34
BuildRequires:	python-pytz
BuildRequires:	python-setuptools >= 1:18.5
BuildRequires:	python-six >= 1.4.1
%if %{with tests}
%if "%{py_ver}" >= "2.7"
BuildRequires:	python-hypothesis >= 1.11.4
%endif
BuildRequires:	python-ipaddress
BuildRequires:	python-iso8601
BuildRequires:	python-pretend
BuildRequires:	python-pytest >= 3.6.0
BuildRequires:	python-pytz
%endif
%endif
%if %{with python3}
BuildRequires:	python3-cffi >= 1.12
BuildRequires:	python3-devel >= 1:3.6
BuildRequires:	python3-setuptools >= 1:18.5
BuildRequires:	python3-six >= 1.4.1
%if %{with tests}
BuildRequires:	python3-hypothesis >= 1.11.4
BuildRequires:	python3-iso8601
BuildRequires:	python3-pretend
BuildRequires:	python3-pytest >= 3.6.0
BuildRequires:	python3-pytz
%endif
%endif
%if %{with doc}
BuildRequires:	python-sphinx_rtd_theme
BuildRequires:	sphinx-pdg-2 >= 1.6.5
%endif
Requires:	openssl >= 3.0.0
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
cryptography is a package designed to expose cryptographic recipes and
primitives to Python developers. Our goal is for it to be your
"cryptographic standard library". It supports Python 2.7, Python 3.4+,
and PyPy.

cryptography includes both high level recipes, and low level
interfaces to common cryptographic algorithms such as symmetric
ciphers, message digests and key derivation functions.

This package contains Python 2 modules.

%description -l pl.UTF-8
cryptography to pakiet zaprojektowany w celu udostępnienia funkcji i
obiektów kryptograficznych programistom Pythona. Celem jest
dostarczenie "standardowej biblioteki kryptograficznej". Obsługuje
Pythona 2.7, Pythona 3.4+ oraz PyPy.

cryptography zawiera zarówno funkcje wysokopoziomowe, jak i
niskopoziomowe interfejsy do popularnych algorytmów kryptograficznych,
takich jak szyfry symetryczne, skróty wiadomości czy funkcje
wyprowadzające klucze.

Ten pakiet zawiera moduły Pythona 2.

%package -n python3-cryptography
Summary:	Crypthography library for Python 3
Summary(pl.UTF-8):	Biblioteka Cryptography dla Pythona 3
Group:		Libraries/Python
Requires:	openssl >= 3.0.0

%description -n python3-cryptography
cryptography is a package designed to expose cryptographic recipes and
primitives to Python developers. Our goal is for it to be your
"cryptographic standard library". It supports Python 2.7, Python 3.4+,
and PyPy.

cryptography includes both high level recipes, and low level
interfaces to common cryptographic algorithms such as symmetric
ciphers, message digests and key derivation functions.

This package contains Python 3 modules.

%description -n python3-cryptography -l pl.UTF-8
cryptography to pakiet zaprojektowany w celu udostępnienia funkcji i
obiektów kryptograficznych programistom Pythona. Celem jest
dostarczenie "standardowej biblioteki kryptograficznej". Obsługuje
Pythona 2.7, Pythona 3.4+ oraz PyPy.

cryptography zawiera zarówno funkcje wysokopoziomowe, jak i
niskopoziomowe interfejsy do popularnych algorytmów kryptograficznych,
takich jak szyfry symetryczne, skróty wiadomości czy funkcje
wyprowadzające klucze.

Ten pakiet zawiera moduły Pythona 3.

%package apidocs
Summary:	API documentation for cryptography module
Summary(pl.UTF-8):	Dokumentacja API modułu cryptography
Group:		Documentation
BuildArch:	noarch

%description apidocs
API documentation for cryptography module.

%description apidocs -l pl.UTF-8
Dokumentacja API modułu cryptography.

%prep
%setup -q -n cryptography-%{version} %{?with_tests:-a1}
%patch0 -p1
%patch2 -p1

# Do not test legacy, disabled by default algorithms
# See man OSSL_PROVIDER-legacy(7)
%{__rm} tests/hazmat/primitives/test_{arc4,blowfish,cast5,idea,seed}.py

%if %{with tests}
%{__mv} cryptography_vectors-%{version}/cryptography_vectors .
%patch1 -p1
%endif

%build
export CFLAGS="%{rpmcflags}"

%if %{with python2}
%py_build

%if %{with tests}
PYTHONPATH=$(echo $(pwd)/build-2/lib.*) \
%{__python} -m pytest tests
%endif
%endif

%if %{with python3}
%py3_build

%if %{with tests}
PYTHONPATH=$(echo $(pwd)/build-3/lib.*) \
%{__python3} -m pytest tests
%endif
%endif

%if %{with doc}
%{__make} -C docs html \
	SPHINXBUILD=sphinx-build-2
%endif

%install
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%py_install

%py_postclean
%endif

%if %{with python3}
%py3_install
%endif

%clean
rm -rf $RPM_BUILD_ROOT

%if %{with python2}
%files
%defattr(644,root,root,755)
%doc AUTHORS.rst README.rst LICENSE LICENSE.APACHE LICENSE.BSD
%dir %{py_sitedir}/cryptography
%{py_sitedir}/cryptography/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat
%{py_sitedir}/cryptography/hazmat/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/backends
%{py_sitedir}/cryptography/hazmat/backends/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/backends/openssl
%{py_sitedir}/cryptography/hazmat/backends/openssl/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/bindings
%{py_sitedir}/cryptography/hazmat/bindings/*.py[co]
%attr(755,root,root) %{py_sitedir}/cryptography/hazmat/bindings/_*.so
%dir %{py_sitedir}/cryptography/hazmat/bindings/openssl
%{py_sitedir}/cryptography/hazmat/bindings/openssl/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives
%{py_sitedir}/cryptography/hazmat/primitives/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives/asymmetric
%{py_sitedir}/cryptography/hazmat/primitives/asymmetric/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives/ciphers
%{py_sitedir}/cryptography/hazmat/primitives/ciphers/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives/kdf
%{py_sitedir}/cryptography/hazmat/primitives/kdf/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives/serialization
%{py_sitedir}/cryptography/hazmat/primitives/serialization/*.py[co]
%dir %{py_sitedir}/cryptography/hazmat/primitives/twofactor
%{py_sitedir}/cryptography/hazmat/primitives/twofactor/*.py[co]
%dir %{py_sitedir}/cryptography/x509
%{py_sitedir}/cryptography/x509/*.py[co]
%{py_sitedir}/cryptography-%{version}-py*.egg-info
%endif

%if %{with python3}
%files -n python3-cryptography
%defattr(644,root,root,755)
%doc AUTHORS.rst README.rst LICENSE LICENSE.APACHE LICENSE.BSD
%dir %{py3_sitedir}/cryptography
%{py3_sitedir}/cryptography/*.py
%{py3_sitedir}/cryptography/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat
%{py3_sitedir}/cryptography/hazmat/*.py
%{py3_sitedir}/cryptography/hazmat/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/backends
%{py3_sitedir}/cryptography/hazmat/backends/*.py
%{py3_sitedir}/cryptography/hazmat/backends/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/backends/openssl
%{py3_sitedir}/cryptography/hazmat/backends/openssl/*.py
%{py3_sitedir}/cryptography/hazmat/backends/openssl/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/bindings
%{py3_sitedir}/cryptography/hazmat/bindings/*.py
%{py3_sitedir}/cryptography/hazmat/bindings/__pycache__
%attr(755,root,root) %{py3_sitedir}/cryptography/hazmat/bindings/_*.so
%dir %{py3_sitedir}/cryptography/hazmat/bindings/openssl
%{py3_sitedir}/cryptography/hazmat/bindings/openssl/*.py
%{py3_sitedir}/cryptography/hazmat/bindings/openssl/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives
%{py3_sitedir}/cryptography/hazmat/primitives/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/asymmetric
%{py3_sitedir}/cryptography/hazmat/primitives/asymmetric/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/asymmetric/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/ciphers
%{py3_sitedir}/cryptography/hazmat/primitives/ciphers/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/ciphers/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/kdf
%{py3_sitedir}/cryptography/hazmat/primitives/kdf/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/kdf/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/serialization
%{py3_sitedir}/cryptography/hazmat/primitives/serialization/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/serialization/__pycache__
%dir %{py3_sitedir}/cryptography/hazmat/primitives/twofactor
%{py3_sitedir}/cryptography/hazmat/primitives/twofactor/*.py
%{py3_sitedir}/cryptography/hazmat/primitives/twofactor/__pycache__
%dir %{py3_sitedir}/cryptography/x509
%{py3_sitedir}/cryptography/x509/*.py
%{py3_sitedir}/cryptography/x509/__pycache__
%{py3_sitedir}/cryptography-%{version}-py*.egg-info
%endif

%if %{with doc}
%files apidocs
%defattr(644,root,root,755)
%doc docs/_build/html/{_downloads,_static,development,hazmat,x509,*.html,*.js}
%endif
%changelog
* Thu Mar 10 2022 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/python-cryptography.git;a=log;h=master

* Wed Mar 09 2022 Jakub Bogusz <qboosh@pld-linux.org> f7fe41d
- added openssl3.0.1 patch

* Tue Mar 08 2022 Jakub Bogusz <qboosh@pld-linux.org> 9ca8acf
- openssl3 patch requires openssl 3+

* Tue Mar 08 2022 Jakub Bogusz <qboosh@pld-linux.org> 7afe5e4
- updated to 3.3.2, use python2 for docs

* Wed Dec 15 2021 Jakub Bogusz <qboosh@pld-linux.org> c43fdbf
- setuptools epoch

* Mon Oct 11 2021 Jan Rękorajski <baggins@pld-linux.org> d3ce35e
- expose SSL_OP_IGNORE_UNEXPECTED_EOF
- disable tests broken due to different assumptions under openssl 3.0.0
- rel 4

* Sun Oct 10 2021 Jan Rękorajski <baggins@pld-linux.org> c9ed311
- disable python3 module build
- disable tests for unsupported algorithms

* Mon Oct 04 2021 Jan Rękorajski <baggins@pld-linux.org> ff0d2aa
- basic openssl 3.0.0 support, testsuite does not pass (mostly unimplemented calls)

* Sun Feb 28 2021 Jan Rękorajski <baggins@pld-linux.org> 3ff5673
- unconditional noarch subpackages

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> 54c5254
- release 3 (by relup.sh)

* Sat Feb 27 2021 Jan Rękorajski <baggins@pld-linux.org> ffd9000
- release 2 (by relup.sh)

* Sun Jan 17 2021 Jakub Bogusz <qboosh@pld-linux.org> 0f792d5
- updated to 3.3.1

* Sun Jun 07 2020 Jakub Bogusz <qboosh@pld-linux.org> 29f64be
- updated to 2.9.2

* Wed Mar 18 2020 Jakub Bogusz <qboosh@pld-linux.org> 503cd91
- really run tests (setup tests just check dependencies, prints deprecation warning and runs 0 tests)
- fixed docs packaging

* Sun Feb 09 2020 Jan Rękorajski <baggins@pld-linux.org> cddf28e
- up to 2.8

* Mon Oct 28 2019 Jan Rękorajski <baggins@pld-linux.org> 34a824d
- rebuild with python 3.8
- release 2 (by relup.sh)

* Sat Oct 05 2019 Jakub Bogusz <qboosh@pld-linux.org> 163a4ef
- enable tests

* Thu Oct 03 2019 Jakub Bogusz <qboosh@pld-linux.org> 094f23d
- noarch apidocs

* Thu Oct 03 2019 Jakub Bogusz <qboosh@pld-linux.org> f63b133
- updated to 2.7

* Thu Nov 29 2018 Jakub Bogusz <qboosh@pld-linux.org> 29d4b67
- updated dependencies

* Thu Nov 22 2018 Arkadiusz Miśkiewicz <arekm@maven.pl> 3e42f45
- up to 2.4.2

